@@ -1,3 +1,20 @@
+/*
+ *  Microfeed - Backend for accessing feed-based services
+ *  Copyright (C) 2009 Henrik Hedberg <henrik.hedberg@innologies.fi>
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License version 2 as published by
+ *  the Free Software Foundation.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ */
 
 #include <microfeed-provider/microfeedprovider.h>
 #include <microfeed-provider/microfeedpublisher.h>
@@ -132,7 +149,7 @@ static DBusObjectPathVTable object_vtable = {
 MicrofeedPublisher* microfeed_publisher_new(const char* publisher_identifier, const char* directory, DBusConnection* connection, MicrofeedPublisherCallbacks* callbacks, void* user_data) {
 	MicrofeedPublisher* publisher;
 	char* separator;
-printf("%s\n", publisher_identifier);	
+
 	publisher = microfeed_memory_allocate(MicrofeedPublisher);
 	publisher->identifier = strdup(publisher_identifier);
 	if (!(separator = strchr(publisher->identifier, MICROFEED_PUBLISHER_IDENTIFIER_SEPARATOR_CHAR)) || separator[1] == 0) {
@@ -152,13 +169,11 @@ printf("%s\n", publisher_identifier);
 		publisher->image_properties[2] = 0;
 
 		if (!dbus_connection_register_object_path(connection, publisher->object_path, &object_vtable, publisher)) {
-printf("dbus\n", publisher_identifier);	
 		
 			return NULL;
 		}
 		
 		if (!(publisher->database_environment = microfeed_database_environment_new(publisher_identifier, directory))) {
-printf("database\n", publisher_identifier);	
 			
 			return NULL;
 		}
