@@ -1,3 +1,20 @@
+/*
+ *  Microfeed - Backend for accessing feed-based services
+ *  Copyright (C) 2009 Henrik Hedberg <henrik.hedberg@innologies.fi>
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License version
+ *  2.1 as published by the Free Software Foundation.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ */
 
 #include <microfeed-subscriber/microfeedsubscriber.h>
 #include <microfeed-common/microfeedmisc.h>
@@ -11,6 +28,8 @@
 #include <sys/types.h>
 #include <dirent.h>
 
+/* TODO: When a publisher (a provider) disconnects, try to reconnect (relaunch) and resubscribe all the feeds automatically. */
+
 struct _MicrofeedSubscriber {
 	char* identifier;
 	DBusConnection* connection;
@@ -148,6 +167,9 @@ MicrofeedSubscriber* microfeed_subscriber_new(const char* identifier, const char
 	return subscriber;
 }
 
+/**
+ * TODO: This function is not yet implemented.
+ */
 void microfeed_subscriber_free(MicrofeedSubscriber* subscriber) {
 	/* TODO */
 }
@@ -513,7 +535,7 @@ static const char* provider_get_unique_connection_name(Provider* provider) {
 
 static void provider_set_unique_connection_name(Provider* provider, const char* unique_connection_name) {
 	char buffer[1024];
-printf("sucn: %s\n", unique_connection_name);
+
 	if (unique_connection_name) {
 		if (provider->unique_connection_name) {
 			provider_set_unique_connection_name(provider, NULL);
